@@ -28,8 +28,6 @@
 #include <string.h>
 
 #include <glib/gi18n.h>
-#include <gtk/gtk.h>
-#include <gtksourceview/gtksource.h>
 
 #include "gedit-file-chooser-dialog.h"
 #include "gedit-encodings-combo-box.h"
@@ -114,16 +112,16 @@ update_newline_visibility (GeditFileChooserDialog *dialog)
 }
 
 static void
-newline_combo_append (GtkComboBox              *combo,
-                      GtkListStore             *store,
-                      GtkTreeIter              *iter,
-                      const gchar              *label,
-                      GeditDocumentNewlineType  newline_type)
+newline_combo_append (GtkComboBox          *combo,
+		      GtkListStore         *store,
+		      GtkTreeIter          *iter,
+		      const gchar          *label,
+		      GtkSourceNewlineType  newline_type)
 {
 	gtk_list_store_append (store, iter);
 	gtk_list_store_set (store, iter, 0, label, 1, newline_type, -1);
 
-	if (newline_type == GEDIT_DOCUMENT_NEWLINE_TYPE_DEFAULT)
+	if (newline_type == GTK_SOURCE_NEWLINE_TYPE_DEFAULT)
 	{
 		gtk_combo_box_set_active_iter (combo, iter);
 	}
@@ -140,7 +138,7 @@ create_newline_combo (GeditFileChooserDialog *dialog)
 	label = gtk_label_new_with_mnemonic (_("L_ine Ending:"));
 	gtk_widget_set_halign (label, GTK_ALIGN_START);
 
-	store = gtk_list_store_new (2, G_TYPE_STRING, GEDIT_TYPE_DOCUMENT_NEWLINE_TYPE);
+	store = gtk_list_store_new (2, G_TYPE_STRING, GTK_SOURCE_TYPE_NEWLINE_TYPE);
 	combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
 	renderer = gtk_cell_renderer_text_new ();
 
@@ -157,19 +155,19 @@ create_newline_combo (GeditFileChooserDialog *dialog)
 	                      store,
 	                      &iter,
 	                      _("Unix/Linux"),
-	                      GEDIT_DOCUMENT_NEWLINE_TYPE_LF);
+	                      GTK_SOURCE_NEWLINE_TYPE_LF);
 
 	newline_combo_append (GTK_COMBO_BOX (combo),
 	                      store,
 	                      &iter,
 	                      _("Mac OS Classic"),
-	                      GEDIT_DOCUMENT_NEWLINE_TYPE_CR);
+	                      GTK_SOURCE_NEWLINE_TYPE_CR);
 
 	newline_combo_append (GTK_COMBO_BOX (combo),
 	                      store,
 	                      &iter,
 	                      _("Windows"),
-	                      GEDIT_DOCUMENT_NEWLINE_TYPE_CR_LF);
+	                      GTK_SOURCE_NEWLINE_TYPE_CR_LF);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
 
@@ -350,12 +348,12 @@ gedit_file_chooser_dialog_init (GeditFileChooserDialog *dialog)
 }
 
 static GtkWidget *
-gedit_file_chooser_dialog_new_valist (const gchar          *title,
-				      GtkWindow            *parent,
-				      GtkFileChooserAction  action,
-				      const GeditEncoding  *encoding,
-				      const gchar          *first_button_text,
-				      va_list               varargs)
+gedit_file_chooser_dialog_new_valist (const gchar             *title,
+				      GtkWindow               *parent,
+				      GtkFileChooserAction     action,
+				      const GtkSourceEncoding *encoding,
+				      const gchar             *first_button_text,
+				      va_list                  varargs)
 {
 	GtkWidget *result;
 	const char *button_text = first_button_text;
@@ -461,11 +459,11 @@ gedit_file_chooser_dialog_new_valist (const gchar          *title,
  * Return value: a new #GeditFileChooserDialog
  */
 GtkWidget *
-gedit_file_chooser_dialog_new (const gchar          *title,
-			       GtkWindow            *parent,
-			       GtkFileChooserAction  action,
-			       const GeditEncoding  *encoding,
-			       const gchar          *first_button_text,
+gedit_file_chooser_dialog_new (const gchar             *title,
+			       GtkWindow               *parent,
+			       GtkFileChooserAction     action,
+			       const GtkSourceEncoding *encoding,
+			       const gchar             *first_button_text,
 			       ...)
 {
 	GtkWidget *result;
@@ -481,8 +479,8 @@ gedit_file_chooser_dialog_new (const gchar          *title,
 }
 
 void
-gedit_file_chooser_dialog_set_encoding (GeditFileChooserDialog *dialog,
-					const GeditEncoding    *encoding)
+gedit_file_chooser_dialog_set_encoding (GeditFileChooserDialog  *dialog,
+					const GtkSourceEncoding *encoding)
 {
 	g_return_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog));
 	g_return_if_fail (GEDIT_IS_ENCODINGS_COMBO_BOX (dialog->priv->option_menu));
@@ -492,7 +490,7 @@ gedit_file_chooser_dialog_set_encoding (GeditFileChooserDialog *dialog,
 				encoding);
 }
 
-const GeditEncoding *
+const GtkSourceEncoding *
 gedit_file_chooser_dialog_get_encoding (GeditFileChooserDialog *dialog)
 {
 	g_return_val_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog), NULL);
@@ -533,8 +531,8 @@ set_enum_combo (GtkComboBox *combo,
 }
 
 void
-gedit_file_chooser_dialog_set_newline_type (GeditFileChooserDialog   *dialog,
-					    GeditDocumentNewlineType  newline_type)
+gedit_file_chooser_dialog_set_newline_type (GeditFileChooserDialog *dialog,
+					    GtkSourceNewlineType    newline_type)
 {
 	g_return_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog));
 	g_return_if_fail (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE);
@@ -543,15 +541,15 @@ gedit_file_chooser_dialog_set_newline_type (GeditFileChooserDialog   *dialog,
 	                newline_type);
 }
 
-GeditDocumentNewlineType
+GtkSourceNewlineType
 gedit_file_chooser_dialog_get_newline_type (GeditFileChooserDialog *dialog)
 {
 	GtkTreeIter iter;
-	GeditDocumentNewlineType newline_type;
+	GtkSourceNewlineType newline_type;
 
-	g_return_val_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog), GEDIT_DOCUMENT_NEWLINE_TYPE_DEFAULT);
+	g_return_val_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog), GTK_SOURCE_NEWLINE_TYPE_DEFAULT);
 	g_return_val_if_fail (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE,
-	                      GEDIT_DOCUMENT_NEWLINE_TYPE_DEFAULT);
+	                      GTK_SOURCE_NEWLINE_TYPE_DEFAULT);
 
 	gtk_combo_box_get_active_iter (GTK_COMBO_BOX (dialog->priv->newline_combo),
 	                               &iter);
