@@ -15,17 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- */
-
-/*
- * Modified by the gedit Team, 2005. See the AUTHORS file for a
- * list of people on the gedit Team.
- * See the ChangeLog files for a list of changes.
- *
- * $Id$
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __GEDIT_PROGRESS_INFO_BAR_H__
@@ -76,12 +66,12 @@ struct _GeditProgressInfoBarClass
  */
 GType 		 gedit_progress_info_bar_get_type 		(void) G_GNUC_CONST;
 
-GtkWidget	*gedit_progress_info_bar_new      		(const gchar          *stock_id,
+GtkWidget	*gedit_progress_info_bar_new      		(const gchar          *icon_name,
 								 const gchar          *markup,
 								 gboolean              has_cancel);
 
-void		 gedit_progress_info_bar_set_stock_image	(GeditProgressInfoBar *bar,
-								 const gchar          *stock_id);
+void		 gedit_progress_info_bar_set_icon_name		(GeditProgressInfoBar *bar,
+								 const gchar          *icon_name);
 
 void		 gedit_progress_info_bar_set_markup		(GeditProgressInfoBar *bar,
 								 const gchar          *markup);
