@@ -37,7 +37,6 @@ struct _GeditStatusbarPrivate
 	GtkWidget     *load_image;
 	GtkWidget     *save_image;
 	GtkWidget     *print_image;
-	GtkWidget     *line_col_button;
 	GtkWidget     *overwrite_mode_label;
 
 	/* tmp flash timeout data */
@@ -92,7 +91,6 @@ gedit_statusbar_class_init (GeditStatusbarClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, GeditStatusbar, load_image);
 	gtk_widget_class_bind_template_child_private (widget_class, GeditStatusbar, save_image);
 	gtk_widget_class_bind_template_child_private (widget_class, GeditStatusbar, print_image);
-	gtk_widget_class_bind_template_child_private (widget_class, GeditStatusbar, line_col_button);
 	gtk_widget_class_bind_template_child_private (widget_class, GeditStatusbar, overwrite_mode_label);
 }
 
@@ -105,10 +103,6 @@ gedit_statusbar_init (GeditStatusbar *statusbar)
 
 	gtk_label_set_width_chars (GTK_LABEL (statusbar->priv->overwrite_mode_label),
 				   get_overwrite_mode_length ());
-
-	/* Line Col button */
-	gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (statusbar->priv->line_col_button),
-	                                _gedit_app_get_line_col_menu (GEDIT_APP (g_application_get_default ())));
 }
 
 /**
@@ -124,13 +118,6 @@ gedit_statusbar_new (void)
 	return GTK_WIDGET (g_object_new (GEDIT_TYPE_STATUSBAR, NULL));
 }
 
-void
-_gedit_statusbar_line_col_button_set_visible (GeditStatusbar *statusbar,
-                                              gboolean        visible)
-{
-	gtk_widget_set_visible (statusbar->priv->line_col_button, visible);
-}
-
 /**
  * gedit_statusbar_set_overwrite:
  * @statusbar: a #GeditStatusbar
@@ -159,35 +146,6 @@ gedit_statusbar_clear_overwrite (GeditStatusbar *statusbar)
 	gtk_label_set_text (GTK_LABEL (statusbar->priv->overwrite_mode_label), NULL);
 }
 
-/**
- * gedit_statusbar_cursor_position:
- * @statusbar: an #GeditStatusbar
- * @line: line position
- * @col: column position
- *
- * Sets the cursor position on the statusbar.
- **/
-void
-gedit_statusbar_set_cursor_position (GeditStatusbar *statusbar,
-				     gint            line,
-				     gint            col)
-{
-	gchar *msg = NULL;
-
-	g_return_if_fail (GEDIT_IS_STATUSBAR (statusbar));
-
-	if ((line >= 0) || (col >= 0))
-	{
-		/* Translators: "Ln" is an abbreviation for "Line", Col is an abbreviation for "Column". Please,
-		use abbreviations if possible to avoid space problems. */
-		msg = g_strdup_printf (_("  Ln %d, Col %d"), line, col);
-	}
-
-	gedit_status_menu_button_set_label (GEDIT_STATUS_MENU_BUTTON (statusbar->priv->line_col_button), msg);
-
-	g_free (msg);
-}
-
 static gboolean
 remove_message_timeout (GeditStatusbar *statusbar)
 {
